@@ -13,22 +13,23 @@ import sys
 from pathlib import Path
 from typing import Any
 
+from loguru import logger
+
 sys.path.append(os.path.dirname(os.path.abspath(__file__)))
-
 from commands.__init__ import __version__
-
 from commands.cmdbase import CmdBase
 from commands.const import (
     DEFAULT_CLI_CONFIG_FILE,
+    DEFAULT_CLI_LOG_FILE_PATH,
     DEFAULT_CONFIG_DIR,
     DEFAULT_LOCAL_STORAGE_PATH,
-    DEFAULT_CLI_LOG_FILE_PATH,
     PROG_NAME,
     SQLITE_DB_PATH,
 )
 from commons.argument_parser import CustomHelpFormatter
 from commons.argument_parser import DsdlArgumentParser as ArgumentParser
 from commons.loghandler import setup_loger
+from commons.stdio import print_stderr
 from utils.admin import initialize_db
 
 sys.path.append(os.path.dirname(os.path.abspath(__file__)))
@@ -50,13 +51,13 @@ class DSDLClient(object):
             Use '%(prog)s <command>' to access/load datasets either from local
             file system or remote cloud storage, can also perform data-preprocessing
             including filtering, visualization, etc.""",
-            epilog="Report bugs to https://github.com/opendatalab/dsdl-sdk/issues",
-            usage=f"{PROG_NAME} GLOBAL_FLAGS | COMMAND [COMMAND_ARGS] [DATASET_NAME]",
+            epilog=
+            "Report bugs to https://github.com/opendatalab/dsdl-sdk/issues",
+            usage=
+            f"{PROG_NAME} GLOBAL_FLAGS | COMMAND [COMMAND_ARGS] [DATASET_NAME]\n",
             formatter_class=CustomHelpFormatter,
         )
-        self.__subparsers = self.__parser.add_subparsers(
-            title="Commands",
-        )
+        self.__subparsers = self.__parser.add_subparsers(title="Commands", )
         self.__init_subcommand_parser()
 
         self.__init_global_flags()  # 初始化全局参数
@@ -75,7 +76,6 @@ class DSDLClient(object):
 
     def __init_cli_config(self) -> Any:
         """
-        TODO 初始化命令行配置
 
         Returns:
 
@@ -144,23 +144,34 @@ class DSDLClient(object):
             if module.is_file() and module.suffix == '.py'
             and not module.name.startswith('_')
         ]  # 获取commands目录下的所有py文件
-        for pkg in pkgs:  # TODO这里的性能是硬性最大的地方，可以通过缓存或者打包的时候预定义方式优化
+        for pkg in pkgs:  # TODO 这里的性能是硬性最大的地方，可以通过缓存或者打包的时候预定义方式优化
             module = importlib.import_module(f'commands.{pkg}')
             for clz_name, clz_obj in inspect.getmembers(module):
                 if inspect.isclass(clz_obj) and issubclass(
                         clz_obj, CmdBase) and not inspect.isabstract(clz_obj):
                     cmd_clz = clz_obj()
-                    subcmd_parser = cmd_clz.init_parser(self.__subparsers)
-                    subcmd_parser.set_defaults(command_handler=cmd_clz.cmd_main)
+                    subcmd_parser = cmd_clz.setup_parser(self.__subparsers)
+                    subcmd_parser.set_defaults(
+                        command_handler=cmd_clz.cmd_main)
                     subcmd_parser._optionals.title = "Command args"
                     subcmd_parser._positionals.title = "Positional arguments"
                     subcmd_parser.formatter_class = CustomHelpFormatter
 
 
 def main():
-    DSDLClient().execute()
+    setup_loger()
+    logger.remove(0)
+    try:
+        DSDLClient().execute()
+    except KeyboardInterrupt as e:
+        print_stderr("\nkeyboard interrupt, exit")
+        exit(-1)
+    except Exception as e:
+        logger.exception(e)
+        print_stderr("unknown error, please see log files at ~/.dsdl/logs")
+        exit(-1)
 
 
 if __name__ == "__main__":
     setup_loger()
-    main()
+    DSDLClient().execute()
